package com.qmth.themis.backend.util;

import com.alibaba.fastjson.JSONObject;
import com.qmth.themis.business.constant.SystemConstant;
import com.qmth.themis.common.util.Result;
import com.qmth.themis.common.util.ResultUtil;

import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.Objects;

/**
 * @Description: http工具
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2020/4/10
 */
public class ServletUtil {

    /**
     * 输出错误
     *
     * @param response
     * @param code
     * @param message
     * @throws IOException
     */
    public static void responseError(ServletResponse response, String code, String message) throws IOException {
        HttpServletResponse httpResponse = (HttpServletResponse) response;
        Result result = ResultUtil.error(code, message);
        String json = JSONObject.toJSONString(result);
        httpResponse.getWriter().print(json);
    }

    /**
     * 获取请求的token
     *
     * @param httpRequest
     * @return
     */
    public static String getRequestToken(HttpServletRequest httpRequest) {
        // 从header中获取token
        String token = httpRequest.getHeader(SystemConstant.TOKEN);
        // 如果header中不存在token，则从参数中获取token
        if (Objects.isNull(token)) {
            token = httpRequest.getParameter(SystemConstant.TOKEN);
        }
        return token;
    }

    /**
     * 获取请求的platform
     *
     * @param httpRequest
     * @return
     */
    public static String getRequestPlatform(HttpServletRequest httpRequest) {
        // 从header中获取platform
        String platform = httpRequest.getHeader(SystemConstant.PLATFORM);
        // 如果header中不存在platform，则从参数中获取platform
        if (Objects.isNull(platform)) {
            platform = httpRequest.getParameter(SystemConstant.PLATFORM);
        }
        return platform;
    }

    /**
     * 获取请求的deviceId
     *
     * @param httpRequest
     * @return
     */
    public static String getRequestDeviceId(HttpServletRequest httpRequest) {
        // 从header中获取platform
        String platform = httpRequest.getHeader(SystemConstant.DEVICE_ID);
        // 如果header中不存在platform，则从参数中获取platform
        if (Objects.isNull(platform)) {
            platform = httpRequest.getParameter(SystemConstant.DEVICE_ID);
        }
        return platform;
    }
}
